@@ -1,11 +1,11 @@
 import logging
 
-from pycarlo.common.settings import MCD_VERBOSE_ERRORS
 from pycarlo.common.files import BytesFileReader, JsonFileReader, TextFileReader
 from pycarlo.common.mcon import MCONParser, ParsedMCON
+from pycarlo.common.settings import MCD_VERBOSE_ERRORS
 
 
-def get_logger(name: str) -> logging:
+def get_logger(name: str) -> logging.Logger:
     """
     Returns a logger with the specified name.
 
@@ -14,8 +14,18 @@ def get_logger(name: str) -> logging:
 
     logger = logging.getLogger(name)
     handler = logging.StreamHandler()
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
     handler.setFormatter(formatter)
     logger.addHandler(handler)
     logger.setLevel(logging.DEBUG if MCD_VERBOSE_ERRORS else logging.CRITICAL)
     return logger
+
+
+__all__ = [
+    "BytesFileReader",
+    "JsonFileReader",
+    "MCONParser",
+    "ParsedMCON",
+    "TextFileReader",
+    "get_logger",
+]
